@@ -9,7 +9,7 @@ import geospacelab.toolbox.utilities.pydatetime as dttool
 from geospacelab.observatory.sc_orbit import OrbitPosition_SSCWS
 
 
-def show_dmsp(sat_id=None, pole='N', band='LBHS', dt_c=None, file_dir=None):
+def show_dmsp(sat_id=None, pole='N', band='LBHS', dt_c=None, file_dir=None, orbit_id=None):
     file_name = 'DMSP_' + dt_c.strftime(
         '%Y-%m-%d_%H%M') + '_' + sat_id.upper() + '_SSUSI_' + band + '_SSJ_SSM_SSIES_' + pole + '.png'
     file_path_out: pathlib.Path = file_dir / file_name
@@ -26,7 +26,7 @@ def show_dmsp(sat_id=None, pole='N', band='LBHS', dt_c=None, file_dir=None):
     # dashboard.dock(datasource_contents=['jhuapl', 'dmsp', 'ssusi', 'edraur'], pole='N', sat_id='f17', orbit_id='46863')
     # If not specified, the data during the whole day will be downloaded.
 
-    dashboard.dock(datasource_contents=['jhuapl', 'dmsp', 'ssusi', 'edraur'], pole=pole, sat_id=sat_id, orbit_id=None,
+    dashboard.dock(datasource_contents=['jhuapl', 'dmsp', 'ssusi', 'edraur'], pole=pole, sat_id=sat_id, orbit_id=orbit_id,
                    time_clip=False)
     ds_s1 = dashboard.dock(
         datasource_contents=['madrigal', 'satellites', 'dmsp', 's1'],
@@ -48,10 +48,10 @@ def show_dmsp(sat_id=None, pole='N', band='LBHS', dt_c=None, file_dir=None):
         ind_t = dashboard.datasets[1].get_time_ind(ut=dt_c)
         if (dts[ind_t] - dt_c).total_seconds() / 60 > 60:  # in minutes
             raise ValueError("The time does not match any SSUSI data!")
-        lbhs_ = lbhs.value[ind_t, :, :]
-        mlat_ = mlat[ind_t, ::]
-        mlon_ = mlon[ind_t, ::]
-        mlt_ = mlt[ind_t, ::]
+        lbhs_ = lbhs.value[ind_t]
+        mlat_ = mlat[ind_t]
+        mlon_ = mlon[ind_t]
+        mlt_ = mlt[ind_t]
         # Add a polar map panel to the dashboard. Currently the style is the fixed MLT at mlt_c=0. See the keywords below:
         panel1 = dashboard.add_polar_map(
             row_ind=0, col_ind=0, style='mlt-fixed', cs='AACGM',
@@ -97,9 +97,9 @@ def show_dmsp(sat_id=None, pole='N', band='LBHS', dt_c=None, file_dir=None):
         panel1.overlay_sc_trajectory(sc_ut=sc_dt, sc_coords=sc_coords, cs='GEO', time_minor_tick=None)
 
         # Overlay sites
-        # panel1.overlay_sites(site_ids=['TRO', 'ESR'],
-        #                      coords={'lat': [69.58, 78.15], 'lon': [19.23, 16.02], 'height': [0, 0]},
-        #                     cs='GEO', marker='^', markersize=3)
+        panel1.overlay_sites(site_ids=['TRO', 'ESR'],
+                             coords={'lat': [69.58, 78.15], 'lon': [19.23, 16.02], 'height': [0, 0]},
+                            cs='GEO', marker='^', markersize=3)
 
         # Add the title and save the figure
         polestr = 'North' if pole == 'N' else 'South'
@@ -209,8 +209,8 @@ def good_events():
 
 if __name__ == "__main__":
     # good_events()
-
-    sat_id = 'f19'
-    dt = datetime.datetime.strptime('20151117 131200', "%Y%m%d %H%M%S")
+    sat_id = 'f18'
+    orbit_id = '61116'
+    dt = datetime.datetime.strptime('20210824 110700', "%Y%m%d %H%M%S")
     file_dir = pathlib.Path(__file__).parent.resolve()
-    show_dmsp(sat_id=sat_id, dt_c=dt, file_dir=file_dir)
\ No newline at end of file
+    show_dmsp(sat_id=sat_id, dt_c=dt, file_dir=file_dir, orbit_id=orbit_id)
\ No newline at end of file
